Package: wilson
Type: Package
Title: Web-Based Interactive Omics Visualization
Version: 2.4.2
Authors@R: c(
    person("Hendrik", "Schultheis", email = "hendrik.schultheis@mpi-bn.mpg.de", role = c("aut", "cre")),
    person("Jens", "Preussner", email = "jens.preussner@mpi-bn.mpg.de", role = "aut"),
    person("Looso", "Mario", email = "mario.looso@mpi-bn.mpg.de", role = "aut"))
Description: Tool-set of modules for creating web-based applications that use plot based strategies to visualize and analyze multi-omics data.
    This package utilizes the 'shiny' and 'plotly' frameworks to provide a user friendly dashboard for interactive plotting.
URL: https://github.com/loosolab/wilson/
BugReports: https://github.com/loosolab/wilson/issues/
License: MIT + file LICENSE
Encoding: UTF-8
Imports: shiny, data.table, ggplot2, plotly (> 4.8.0), scales,
        shinydashboard, DT (>= 0.3), colourpicker, RColorBrewer,
        shinyjs, viridis, rje, grDevices, grid, plyr, circlize,
        ComplexHeatmap, stats, gplots, reshape, rintrojs, RJSONIO,
        ggrepel (>= 0.6.12), DESeq2, rjson, FactoMineR, factoextra,
        heatmaply (>= 0.14.1), shinycssloaders, log4r, openssl,
        methods, R6, zip, shinyWidgets
RoxygenNote: 7.1.1
biocViews:
Suggests: knitr, rmarkdown, testthat, stringi, utils
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2021-04-19 09:17:56 UTC; hschult
Author: Hendrik Schultheis [aut, cre],
  Jens Preussner [aut],
  Looso Mario [aut]
Maintainer: Hendrik Schultheis <hendrik.schultheis@mpi-bn.mpg.de>
Repository: CRAN
Date/Publication: 2021-04-19 09:40:02 UTC
Built: R 4.6.0; ; 2026-05-01 05:32:02 UTC; unix
