# Generated by roxygen2: do not edit by hand

export(Clarion)
export(and)
export(andUI)
export(colorPicker)
export(colorPickerUI)
export(columnSelector)
export(columnSelectorUI)
export(create_geneview)
export(create_heatmap)
export(create_pca)
export(create_scatterplot)
export(featureSelector)
export(featureSelectorUI)
export(geneView)
export(geneViewUI)
export(global_cor_heatmap)
export(global_cor_heatmapUI)
export(heatmap)
export(heatmapUI)
export(install_app)
export(label)
export(labelUI)
export(limit)
export(limitUI)
export(marker)
export(markerUI)
export(orNumeric)
export(orNumericUI)
export(orTextual)
export(orTextualUI)
export(parse_MaxQuant)
export(parser)
export(pca)
export(pcaUI)
export(scatterPlot)
export(scatterPlotUI)
export(set_logger)
export(tobias_parser)
export(transformation)
export(transformationUI)
import(data.table)
importFrom(R6,R6Class)
